@@ -1,6 +1,6 @@
 /* GNU Chess 6 - components.cc - Pipes shared across modules
 
-   Copyright (c) 2001-2015 Free Software Foundation, Inc.
+   Copyright (c) 2001-2017 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -28,6 +28,7 @@
 #include <cstring>
 #include <unistd.h>
 #include <pthread.h>
+#include <signal.h>
 
 #include "frontend/common.h"
 #include "components.h"
@@ -46,12 +47,17 @@ namespace engine {
   int main_engine(int argc,char *argv[]);
 }
 
+/* Input thread */
+pthread_t input_thread;
+
 /* Adapter thread */
 pthread_t adapter_thread;
 
 /* Engine thread */
 pthread_t engine_thread;
 
+int pipefd_i2f[2];
+
 /* Pipes to communicate frontend and adapter */
 int pipefd_f2a[2];
 int pipefd_a2f[2];
@@ -60,6 +66,30 @@ int pipefd_a2f[2];
 int pipefd_a2e[2];
 int pipefd_e2a[2];
 
+/*
+ * Entry point for the input thread
+ */
+/*void *input_func(void *arg)
+{
+  return 0;
+}*/
+
+/*
+ * Starts the input on a separate thread.
+ */
+
+void InitInputThread()
+{
+  /* Create pipes to communicate input and frontend. */
+  if ( pipe( pipefd_i2f ) != 0 ) {
+    printf( "Error while creating pipe.\n" );
+    exit( 1 );
+  }
+
+  /* Start input thread */
+  pthread_create(&input_thread, NULL, input_func, NULL);
+}
+
 /*
  * Entry point for the adapter thread
  */
@@ -139,3 +169,8 @@ void TerminateAdapterEngine()
   }
 }
 
+void TerminateInput()
+{
+  pthread_cancel( input_thread );
+  pthread_join( input_thread, NULL );
+}
