@@ -2,7 +2,7 @@
 
    GNU Chess frontend
 
-   Copyright (C) 2001-2011 Free Software Foundation, Inc.
+   Copyright (C) 2001-2020 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -29,6 +29,7 @@
 #define COMMON_H
 
 #include <config.h>
+#include <pthread.h>
 
 #ifndef __GNUC__
 # define __attribute__(x)
@@ -341,6 +342,7 @@ extern int phase;
 
 extern short bookfirstlast;
 extern short graphicmodeoutput;
+extern short coords;
 extern short pgnloaded; /* was pgn game loaded by command pgnreplay */
 extern int pgncnt; /* total moves loaded in pgn game */
 
@@ -428,7 +430,7 @@ void FilterIllegalMoves (short);
 void MakeMove (int, int *);
 void UnmakeMove (int, int *);
 void SANMove (int, int);
-leaf *ValidateMove (char *);
+leaf *ValidateMove (char *, char *cleanMove=0);
 leaf *IsInMoveList (int, int, int, char);
 char *AlgbrMove (int);
 
@@ -464,7 +466,6 @@ void PGNReadFromFile (const char *, int showheading);
 
 /*  Some output routines */
 void ShowMoveList (int);
-void ShowSmallBoard (void);
 void ShowBoard (void);
 void ShowCBoard (void);
 void ShowMvboard (void);
@@ -483,6 +484,38 @@ void DBWritePlayer (void);
 int DBSearchPlayer (const char *player);
 void DBUpdatePlayer (const char *player, const char *resultstr);
 
+/* Input thread and thread function */
+extern pthread_t input_thread;
+void *input_func(void *);
+
+/*
+ * Status variable used by the input thread to signal
+ * pending input. Thought about using flags for this
+ * but this can be refined and is conceptually different
+ * from flags.
+ */
+enum {
+  INPUT_NONE,
+  INPUT_AVAILABLE
+};
+extern volatile int input_status;
+
+/*
+ * Function to wake up the input thread, should be called after
+ * input has been parsed.
+ */
+void input_wakeup(void);
+
+/* Wait for input. */
+
+//void wait_for_input(void);
+
+/*
+ * Input routine, initialized to one of the specific
+ * input routines. The given argument is the prompt.
+ */
+extern void (*get_line) (char *);
+
 #define BUF_SIZE 4096
 
 #define MAXSTR 128
@@ -628,12 +661,6 @@ void SetDataToEngine( const char data[] );
  */
 void ExpectAnswerFromEngine( int );
 
-/*
- * If the prompt must be displayed on the standard output, according to
- * the current state, it is displayed.
- */
-void ShowPrompt( void );
-
 /*
  * Extracts a command from the user input buffer.
  */
