@@ -2,7 +2,7 @@
  
    GNU Chess frontend
 
-   Copyright (C) 2001-2015 Free Software Foundation, Inc.
+   Copyright (C) 2001-2020 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -557,6 +557,6 @@ void ForwardEngineOutputToUser( void )
     /* Write data to output */
     assert( nread < BUF_SIZE-1 );
     engineinputaux[nread] = '\0';
-    write( STDOUT_FILENO, engineinputaux, nread );
+    ssize_t r = write( STDOUT_FILENO, engineinputaux, nread );  // TODO Handle return value
   }
 }
