@@ -1,6 +1,6 @@
 /* GNU Chess 6 - main.cc - entry point
 
-   Copyright (c) 2001-2017 Free Software Foundation, Inc.
+   Copyright (c) 2001-2020 Free Software Foundation, Inc.
 
    GNU Chess is based on the two research programs
    Cobalt by Chua Kong-Sian and Gazebo by Stuart Cracraft.
@@ -218,7 +218,7 @@ extern char userinputbuf[];
 
 void EndProg( int sig __attribute__ ((unused)) )
 {
-    system( "stty sane" );
+    int r = system( "stty sane" );  // TODO Handle return value
     exit(0);
 }
 
@@ -322,7 +322,7 @@ int main (int argc, char *argv[])
        errno = 0; /* zero error indicator */
        opt_memory = strtol (optarg, &endptr, 10);
        if ( errno != 0 || *endptr != '\0' ){
-         printf(_("Memory out of Range or Invalid\n"));
+         printf(_("Memory out of range or invalid.\n"));
          return(1);
        }
        break;
@@ -339,13 +339,13 @@ int main (int argc, char *argv[])
        }
        errno = 0; /* zero error indicator */
        if ( strlen( optarg ) > MAXSTR ) {
-         printf( _("File name is too long (max = %d)\n"), MAXSTR );
+         printf( _("File name is too long (max = %d).\n"), MAXSTR );
          return(1);
        }
        strcpy( opt_addbook, optarg );
        break;
      default:
-       puts (_("Option Processing Failed\n"));
+       puts (_("Option processing failed.\n"));
        abort();
      }
   } /* end of getopt_long style parsing */
@@ -391,7 +391,7 @@ Copyright (C) %s Free Software Foundation, Inc.\n\
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n\
 This is free software: you are free to change and redistribute it.\n\
 There is NO WARRANTY, to the extent permitted by law.\n"),
-             "2017" );
+             "2020" );
   }
 
   /* If a usage statement is required output it here */
@@ -412,8 +412,9 @@ There is NO WARRANTY, to the extent permitted by law.\n"),
   sigaction( SIGINT, &action, NULL );
 
   Initialize ();
-  InitFrontend();
   if ( ! (flags & UCI ) ) {
+    /* Initialize the frontend */
+    InitFrontend();
     /* Initialize the adapter, which in turn initializes the engine */
     InitAdapter();
   } else {
